@@ -82,12 +82,18 @@ class Logger:
 
     # info 级别日志
     def info(self, info):
+        self._logger.addHandler(self.file_handler)
         self._logger.info(info)
+        self._logger.removeHandler(self.file_handler)
 
     # error 级别日志
     def error(self, error):
+        self._logger.addHandler(self.file_handler)
         self._logger.error(error)
+        self._logger.removeHandler(self.file_handler)
 
     # waring 级别日志
     def waring(self, waring):
+        self._logger.addHandler(self.file_handler)
         self._logger.warning(waring)
+        self._logger.removeHandler(self.file_handler)
